@@ -21,6 +21,7 @@ from logging import getLogger
 from typing import Optional
 
 from requests import RequestException, Session, codes
+from requests.adapters import HTTPAdapter
 
 from gitlabracadabra.auth_info import AuthInfo
 from gitlabracadabra.packages.package_file import PackageFile
@@ -46,6 +47,8 @@ class Destination(object):
         """
         self._log_prefix = log_prefix
         self._session = Session()
+        self._session.mount('http://', HTTPAdapter(max_retries=3))
+        self._session.mount('https://', HTTPAdapter(max_retries=3))
 
     def __del__(self) -> None:  # noqa:WPS603
         """Destroy a registry connection."""
@@ -148,7 +151,7 @@ class Destination(object):
         """
         return self.head_url(package_file)
 
-    def files_key(self, package_file: PackageFile) -> Optional[str]:
+    def files_key(self, package_file: PackageFile) -> Optional[str]:  # noqa: WPS324
         """Get files key, to upload to. If None, uploaded as body.
 
         Args:
