@@ -16,12 +16,19 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from unittest import skipIf
+
+from gitlab import __version__ as gitlab_version
+
+from packaging.version import parse as version_parse
+
 from gitlabracadabra.objects.application_settings import GitLabracadabraApplicationSettings
 from gitlabracadabra.tests import my_vcr
 from gitlabracadabra.tests.case import TestCaseWithManager
 
 
 class TestApplicationSettings(TestCaseWithManager):
+    @skipIf(version_parse(gitlab_version) < version_parse('3.7.0'), 'python-gitlab without proper array support')
     @my_vcr.use_cassette
     def test_settings(self, cass):
         # On the GitLab rails console, before recording:
